==> haskell-annotated-wl-pprint-0.7.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
key: annotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
license: BSD3
maintainer: david@davidchristiansen.dk
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
author: Daan Leijen, David Raymond Christiansen
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
abi: 644a92ff1e8f12335485610cb871afd8
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-annotated-wl-pprint-0.7.0-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
key: annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
license: BSD3
maintainer: david@davidchristiansen.dk
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
author: Daan Leijen, David Raymond Christiansen
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
abi: 9fa3d60a9e7f2c957d7e8d120bc3f791
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
